@@ -33,7 +33,7 @@ Fetcher::Fetcher()
     }
 }
 
-void Fetcher::fetchFavorites()
+void Fetcher::fetchFavorites(bool force)
 {
     static QAtomicInteger<qsizetype> channelCounter = 0; // reference counter to determine when all channels have been fetched
 
@@ -49,6 +49,18 @@ void Fetcher::fetchFavorites()
 
     setFavoritesPercentage(0);
 
+    if (favoriteChannels.empty()) {
+        setFavoritesPercentage(100);
+        return;
+    }
+
+    if (force) {
+        Database::instance().clearPrograms();
+        for (const ChannelId &channelId : favoriteChannels) {
+            Q_EMIT channelUpdated(channelId);
+        }
+    }
+
     for (const ChannelId &channelId : favoriteChannels) {
         Q_EMIT startedFetchingChannel(channelId);
         m_fetcherImpl->fetchProgram(
@@ -98,7 +110,7 @@ void Fetcher::fetchProgramDescription(const ChannelId &channelId, const ProgramI
 {
     m_fetcherImpl->fetchProgramDescription(channelId, programId, url, [this, channelId, programId](const QString &description) {
         Database::instance().updateProgramDescription(programId, description);
-        Q_EMIT programUpdated(programId);
+        Q_EMIT programDescriptionUpdated(programId, description);
     });
 }
 
